// ***************************************************************************
// Implementation System Includes
// ***************************************************************************

#include <be/interface/View.h>

// ***************************************************************************
// Implementation Project Includes
// ***************************************************************************

#include "Connection.h"
#include "ConnectorView.h"
#include "EavesdropperMain.h"

// ***************************************************************************
// Implementation Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Type Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Variable Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Variable Definitions
// ***************************************************************************

// ***************************************************************************
// PUBLIC Member Function Definitions
// ***************************************************************************

// ===========================================================================
// Constructor
// ===========================================================================

Connection::Connection(ConnectorView* sourceConnector,
	ConnectorView* destinationConnector)
{
	this->sourceConnector = sourceConnector;
	this->destinationConnector = destinationConnector;
}

// ===========================================================================
// Draw
// ===========================================================================

void
Connection::Draw(BView* destinationView)
{
	if (destinationView->LockLooper())
	{
		destinationView->SetDrawingMode(B_OP_OVER);
		
		// Erase the old line.
		destinationView->SetHighColor(COLOR_BACKGROUND);
		destinationView->StrokeLine(sourcePoint, destinationPoint);

		// Get the endpoints of the new line. Note that we have to add the
		// top-left coordinates of the destination view's bounds rectangle
		// to the frames of the connectors, to compensate for the scrolling
		// of the destination view.
		BRect sourceFrame = sourceConnector->Frame();
		float sourceX = sourceFrame.left
			+ sourceFrame.Width()/2
			+ destinationView->LeftTop().x;
		float sourceY = sourceFrame.top
			+ sourceFrame.Height()/2
			+ destinationView->LeftTop().y;
		sourcePoint.Set(sourceX, sourceY);

		BRect destFrame = destinationConnector->Frame();
		float destX = destFrame.left
			+ destFrame.Width()/2
			+ destinationView->LeftTop().x;
		float destY = destFrame.top
			+ destFrame.Height()/2
			+ destinationView->LeftTop().y;
		destinationPoint.Set(destX, destY);

		// Draw the new line.
		destinationView->SetHighColor(COLOR_CONNECTION);
		destinationView->StrokeLine(sourcePoint, destinationPoint);
		
		destinationView->UnlockLooper();
	}
}

// ***************************************************************************
// PROTECTED Member Function Definitions
// ***************************************************************************

// ***************************************************************************
// PRIVATE Member Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Definitions
// ***************************************************************************

// ***************************************************************************
// Global Function Definitions
// ***************************************************************************

// ***************************************************************************
// Implementation Function Definitions
// ***************************************************************************
