#ifndef EAVESDROPPER_CONNECTORVIEW_H
#define EAVESDROPPER_CONNECTORVIEW_H

// ***************************************************************************
// System Includes
// ***************************************************************************

#include <be/interface/View.h>

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

class InfoWindow;

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

/** The width of a connector (in pixels). */
const float CONNECTOR_WIDTH = 9;

/** The height of a connector (in pixels). */
const float CONNECTOR_HEIGHT = 9;

// ***************************************************************************
// Type Definitions
// ***************************************************************************

class LiveNodesView;

// ***************************************************************************
// Class Definition
// ***************************************************************************

/**
 * The ConnectorView class represents an input or output connector on a node.
 */
class ConnectorView : public BView
{
public:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

	/**
	 * Constructor.
	 *
	 * @param infoWindow Pointer to the Information Window.
	 * @param mediaInput Pointer to the connector's media_input structure if
	 *        the connector is an input, 0 otherwise.
	 * @param mediaOutput Pointer to the connector's media_output structure
	 *        if the connector is an output, 0 otherwise.
	 * @param isConnected Whether the connector is free or connected to the
	 *        connector of another node.
	 */
	ConnectorView(InfoWindow* infoWindow,
		media_input* mediaInput,
		media_output* mediaOutput,
		bool isConnected);

	/** Automatically generated copy constructor. */
	// ConnectorView(const ConnectorView& old);

	/** Destructor. */
	virtual ~ConnectorView(void);

	/** Automatically generated assignment operator. */
	// ConnectorView& operator=(ConnectorView& right);

	/** Handles the messages that this view receives. */
	virtual void MessageReceived(BMessage* message);

	/** Draws the view. */
	virtual void Draw(BRect updateRect);

	/** Handles dragging of the view. */
	virtual void MouseDown(BPoint where);

	/** Figures out whether the mouse is currently rolling over the view. */
	virtual void MouseMoved(BPoint point,
		uint32 transit,
		const BMessage* message);

	/** Selects or de-selects this connector. */
	void SetSelected(bool flag);

	/** Determines whether this connector is selected. */
	bool IsSelected();

	/** Determines whether this connector is an input. */
	bool IsInput();

	/** Determines whether this connector is an output. */
	bool IsOutput();

	/** Returns the media_input structure that describes this connector. */
	media_input* GetInput();

	/** Returns the media_output structure that describes this connector. */
	media_output* GetOutput();

	/** Determines whether this connector is connected. */
	bool IsConnected();

protected:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

private:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	/** Pointer to the Information window. */
	InfoWindow* infoWindow;

	/** Whether this connector is currently selected. */
	bool isSelected;

	/** Whether the mouse is currently hovering over this connector. */
	bool isRollover;		

	/**
	 * The connector's media_input structure, or 0 if the connector is not
	 * an input.
	 */
	media_input* mediaInput;

	/**
	 * The connector's media_output structure, or 0 if the connector is not
	 * an output.
	 */
	media_output* mediaOutput;

	/**
	 * Whether the connector is connected to a connector from another node.
	 */
	bool isConnected;
	
	// Member Function Definitions ===========================================
};

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

#endif // EAVESDROPPER_CONNECTORVIEW_H
