#ifndef FAIL_H
#define FAIL_H

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

/**
 * Generic test for success on any status value.
 *
 * Usage: if (SUCCEEDED(whatever)) { ... }
 *
 * @see The BeOS include file "Errors.h" (The Be Headers, Support Kit)
 * @see The Win32 include file "Winerror.h"
 */
#define SUCCEEDED(Status) ((status_t)(Status) >= B_OK)

/**
 * Generic test for failure on any status value.
 *
 * Usage: if (FAILED(whatever)) { ... }
 *
 * @see The BeOS include file "Errors.h" (The Be Headers, Support Kit)
 * @see The Win32 include file "Winerror.h"
 */
#define FAILED(Status) ((status_t)(Status) < B_OK)

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

/**
 * Shows a modal alert box.
 *
 * This is a simple function that takes away the hassle of setting up and
 * displaying a BAlert window yourself in the case of a failure. The type of
 * the alert is always B_STOP_ALERT.
 *
 * @param text The text that will be displayed in the alert box.
 * @return Always returns B_ERROR.
 *
 * @see BAlert (The Be Book, Interface Kit)
 */
status_t Fail(const char* text);

#endif // FAIL_H
