#ifndef EAVESDROPPER_LIVENODEVIEW_H
#define EAVESDROPPER_LIVENODEVIEW_H

// ***************************************************************************
// System Includes
// ***************************************************************************

#include <be/media/MediaNode.h>

// ***************************************************************************
// Project Includes
// ***************************************************************************

#include "StyleGuideDefs.h"         // Standard type and constant definitions.
#include "AbstractNodeView.h"

// ***************************************************************************
// External Name Declarations
// ***************************************************************************

class Connection;
class ConnectorView;
class LiveNodesView;

// ***************************************************************************
// External Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Constant Definitions
// ***************************************************************************

// ***************************************************************************
// Type Definitions
// ***************************************************************************

// ***************************************************************************
// Class Definition
// ***************************************************************************

/**
 * The LiveNodeView class represents a live media node.
 */
class LiveNodeView : public AbstractNodeView
{
public:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

	/**
	 * Constructor.
	 *
	 * @param infoWindow Pointer to the Information window.
	 * @param liveNodesView Pointer to the LiveNodesView that this node
	 *        belongs to.
	 * @param liveNodeInfo The live_node_info structure that describes this
	 *        media node.
	 */
	LiveNodeView(InfoWindow* infoWindow,
		LiveNodesView* liveNodesView,
		live_node_info liveNodeInfo);

	/** Automatically generated copy constructor. */
	// LiveLiveNodeView(const LiveNodeView& old);

	/** Destructor. */
	virtual ~LiveNodeView(void);

	/** Automatically generated assignment operator. */
	// LiveNodeView& operator=(LiveNodeView& right);

	/** Adds this node's connectors to the LiveNodesView. */
	virtual void AttachedToWindow(void);

	/** Deletes this node's connectors from the LiveNodesView. */
	virtual void DetachedFromWindow(void);

	/** Overridden to move this node's connector views as well. */
	virtual void MoveTo(BPoint point);

	/** Draws the view. */
	virtual void Draw(BRect updateRect);

	/** Starts tracking the mouse to see whether the user wants to drag. */
	virtual void MouseDown(BPoint where);

	/** Ends dragging of the view. */
	virtual void MouseUp(BPoint where);
	
	/**
	 * Figures out whether the mouse is currently rolling over the view,
	 * and determines whether the user wants to drag it.
	 */
	virtual void MouseMoved(BPoint point,
		uint32 transit,
		const BMessage* message);
	
	/** Returns the live_node_info structure that describes this node. */
	live_node_info GetLiveNodeInfo(void);
	
	/** Returns the media_node structure that describes this node. */
	media_node GetNode(void);

	/**
	 * Returns the list of ConnectorViews that describe this node's inputs.
	 */
	BList* GetInputConnectors(void);
	
	/**
	 * Returns the list of ConnectorViews that describe this node's outputs.
	 */
	BList* GetOutputConnectors(void);

	/**
	 * Returns the list of media_file_format structures that describe the
	 * file formats that this node supports.
	 */
	BList* GetFileFormats(void);

	/**
	 * Returns the list of media_node_attribute structures that describe the
	 * attributes of this node.
	 */
	BList* GetAttributes(void);
		
protected:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	// Member Function Definitions ===========================================

private:
	// Constant Definitions ==================================================

	// Type Definitions ======================================================

	// Attribute Definitions =================================================

	/** The LiveNodesView container that this node belongs to. */
	LiveNodesView* liveNodesView;

	/** The live_node_info structure that describes this media node. */
	live_node_info liveNodeInfo;

	/** The ConnectorViews of the node's inputs. */
	BList* inputConnectors;

	/** The ConnectorViews of the node's outputs. */
	BList* outputConnectors;

	/** Pointers to the media_file_format structures of this node. */
	BList* fileFormats;

	/** Pointers to the media_node_attribute structures of this node. */
	BList* attributes;

	/**
	 * Whether we're currently tracking the mouse to see if the user wants
	 * to drag the view.
	 */
	bool isTracking;
	
	/** Where in the view the user clicked. */
	BPoint clickPoint;

	// Member Function Definitions ===========================================

	/**
	 * Queries the Media Server for all interesting information on this node,
	 * such as its free and connected inputs and outputs, the file formats it
	 * supports, and so on, and caches this information for future reference.
	 */	
	void GetNodeInfo(void);
};

// ***************************************************************************
// Global Variable Declarations
// ***************************************************************************

// ***************************************************************************
// Inline Function Definitions
// ***************************************************************************

// ***************************************************************************
// Helper Function Declarations
// ***************************************************************************

// ***************************************************************************
// Global Function Declarations
// ***************************************************************************

#endif // EAVESDROPPER_LIVENODEVIEW_H
